# Vega Python Client

Python client for the Vega API: https://gitee.com/kumo-pub/kumosdk-py

## 安装

```
$ pip install kumosdk
```

You can also add `kumosdk` to your project's `requirements.txt`.

## 使用

一些例子 [here](https://gitee.com/kumo-pub/kumosdk-py/blob/master/examples/collection_operations.py).

详细请参见API文档 [API documentation](http://kumo-ai.tech/docs).

## Compatibility

| Vega Server | kumosdk-py |
|-------------|------------|
| \>= v1.0.8  | \>= v0.3.2 |

## Contributing

Bug reports and pull requests are welcome on Gitee at [https://gitee.com/kumo-pub/kumosdk-py].

## License

`vega-py` is distributed under the Apache 2 license.



